# -*- coding: utf-8 -*-
# Copyright 2023 Cohesity Inc.

class ObjectClassSearchPrincipalsEnum(object):

    """Implementation of the 'objectClass_SearchPrincipals' enum.

    TODO: type enum description here.

    Attributes:
        KUSER: TODO: type description here.
        KGROUP: TODO: type description here.
        KCOMPUTER: TODO: type description here.
        KWELLKNOWNPRINCIPAL: TODO: type description here.
        KSERVICEACCOUNT: TODO: type description here.

    """

    KUSER = 'kUser'

    KGROUP = 'kGroup'

    KCOMPUTER = 'kComputer'

    KWELLKNOWNPRINCIPAL = 'kWellKnownPrincipal'

    KSERVICEACCOUNT = 'kServiceAccount'

